==> haskell-xml-hamlet-0.5.0.2-298-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-ICcsh17RDbt4vXS3yyHgsC
key:                  xml-hamlet-0.5.0.2-ICcsh17RDbt4vXS3yyHgsC
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  229dab2f98ae956521d84761373c0465
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-ICcsh17RDbt4vXS3yyHgsC
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1
    shakespeare-2.1.3-VIfs5X4agoEHzM5LEBqg2 template-haskell-2.19.0.0
    text-2.0.2 xml-conduit-1.9.1.4-9KZOZdZcRoc9hnwp2o5jJ5

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.5.0.2-299-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-7VMhXiiwgzq72OkiJFmJ8V
key:                  xml-hamlet-0.5.0.2-7VMhXiiwgzq72OkiJFmJ8V
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  9e00d920033fa364fba2e678122fa4d6
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-7VMhXiiwgzq72OkiJFmJ8V
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1
    shakespeare-2.1.3-8CUSzaeWw65JSgXySG4QSZ template-haskell-2.19.0.0
    text-2.0.2 xml-conduit-1.9.1.4-qsvvv4PkcvFS9Cgy8VM0U

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
